@@ -22,46 +22,49 @@ class Model(keras.Model):
     DEFAULT_KEY=NAME
     SEGMENT='segment'
     GLOBAL_POOLING='global_pooling'
+    DEFAULT_CLASSIFIER=SEGMENT
 
 
+    #
+    # PUBLIC
+    #
     def __init__(self,
-            nb_classes=None,
-            classifier_config={},
-            classifier_key_path=None,
-            classifier_is_file_path=False,
-            classifier_cfig_dir=load.TFBOX,
             is_skip=False,  
             name=NAME,
             named_layers=True,
             noisy=True):
         super(Model, self).__init__()
+        self.classifier=None
         self.is_skip=is_skip
         self.model_name=name
         self.named_layers=named_layers
-        # classifier
-        if nb_classes:
-            if isinstance(classifier_config,str):
-                classifier_config=load.config(
-                        cfig=classifier_config,
-                        key_path=classifier_key_path,
-                        is_file_path=classifier_is_file_path,
-                        cfig_dir=classifier_cfig_dir,
-                        noisy=noisy )
-            classifier_type=classifier_config.pop('classifier_type')
+
+
+    def set_classifier(self,
+            nb_classes,
+            config,
+            file_name='classifier',
+            folder=load.TFBOX):
+        if nb_classes and config:
+            if config is True:
+                config={}
+            elif isinstance(config,str):
+                config={ 'classifier_type': config }
+            else:
+                config=load.config(config,file_name,folder)
+            classifier_type=config.pop( 'classifier_type', self.DEFAULT_CLASSIFIER )
             if classifier_type==Model.SEGMENT:
                 self.classifier=blocks.SegmentClassifier(
                     nb_classes=nb_classes,
-                    **classifier_config)
+                    **config)
             elif classifier_type==Model.GLOBAL_POOLING:
                 raise NotImplementedError('TODO: GAPClassifier')
-            elif classifier_type:
-                raise NotImplementedError(f'{classifier_type} is not a valid classifier')
             else:
-                self.classifier=None
+                raise NotImplementedError(f'{classifier_type} is not a valid classifier')
         else:
-            self.classifier=None
-
+            self.classifier=False
 
+        
     def output(self,x):
         if self.classifier:
             x=self.classifier(x)
