@@ -82,6 +82,63 @@ def upsample(
     return x
 
 
+
+def build_block(config,btype=None,index=None):
+    config=_config_dict(config)
+    btype=config.pop('btype',btype or DEFAULT_BTYPE)
+    name=config.get('name')
+    if index and name:
+        config['name']=f'{name}.{index}'
+    return get(btype)(**config)
+
+
+def build_blocks(config,indexed=True,singles_as_block=False):
+    block_stack=[]
+    config=_config_dict(config)
+    layers=config.pop('layers',[{}])
+    nb_repeats=config.pop('nb_repeats',1)
+    as_block=singles_as_block and (nb_repeats==1) and (layers==[{}])
+    for i in range(nb_repeats):
+        for j,c in enumerate(layers):
+            if indexed and (not as_block):
+                index=f'{i}-{j}'
+            else:
+                index=None
+            cfg=config.copy()
+            cfg.update(_config_dict(c))
+            block_stack.append(
+                build_block(cfg,index=index))
+    if as_block:
+        return block_stack[0]
+    else:
+        return block_stack
+
+
+def _config_dict(config):
+    if not config:
+        config={}
+    elif isinstance(config,str):
+        config={
+            'btype': config,
+        }
+    elif isinstance(config,int):
+        config={
+            'btype': INT_BTYPE,
+            'filters': config,
+        }
+    else:
+        nb_keys=len(config)
+        if nb_keys==1:
+            key, value=next(iter(config.items()))
+            if key in BLOCKS:
+                btype=key
+                config=value
+            else:
+                btype=DEFAULT_BTYPE
+            config['btype']=btype
+    return config.copy()
+
+
 #
 # GENERAL BLOCKS 
 #
@@ -613,8 +670,14 @@ class Residual(keras.Model):
             identity=False,
             filters=None,
             residual=True,
+            concat=False,
             **config):
-        self.block=block
+        super(Residual, self).__init__()
+        if isinstance(block,dict):
+            self.block=build_blocks(block)
+        else:
+            self.block=block
+        self.concat=concat
         self.residual=self._residual(
             residual,
             identity,
@@ -629,8 +692,16 @@ class Residual(keras.Model):
             res=self.residual(x)
         else:
             res=False
-        if res:
-            x=layers.add([res,self.block(x)])
+        if isinstance(self.block,list):
+            for b in self.block:
+                x=b(x)        
+        else:
+            x=self.block(x)
+        if res is not False:
+            if self.concat:
+                x=layers.Concatenate()([res,x])
+            else:
+                x=layers.add([res,x])
         return x
 
 
@@ -686,30 +757,6 @@ class SegmentClassifier(keras.Model):
     AUTO='auto'
 
 
-
-    #
-    # STATIC
-    #
-    @staticmethod
-    def from_config(
-            cfig='blocks',
-            key_path='segment_k3',
-            cfig_dir=load.TFBOX,
-            is_file_path=False,
-            config_string=None,
-            **kwargs):
-        config=load.config(
-            cfig=cfig,
-            key_path=key_path,
-            cfig_dir=cfig_dir,
-            is_file_path=is_file_path,
-            config_string=config_string,
-            **kwargs)
-        print('SegmentClassifier:')
-        pprint(config)
-        return SegmentClassifier(**config)
-
-
     #
     # PUBLIC
     #
@@ -785,7 +832,10 @@ class SegmentClassifier(keras.Model):
 
     def _filters_list(self,filters_list,filters,nb_classes,depth):
         if filters_list:
-            if filters_list[-1]!=nb_classes:
+            out_filters=filters_list[-1]
+            if h.noney(out_filters):
+                filters_list[-1]=nb_classes
+            elif filters_list[-1]!=nb_classes:
                 raise ValueError('last filters value must equal nb_classes')
         else:
             if filters is False:
@@ -822,6 +872,7 @@ BLOCKS={
     'conv': Conv,
     'stack': Stack,
     'group': Group,
+    'residual': Residual,
     'squeeze_excitation': SqueezeExcitation,
     'aspp': ASPP,
     'segment_classifier': SegmentClassifier
@@ -831,7 +882,10 @@ ACTIVATIONS={
     'sigmoid': activations.sigmoid,
     'softmax': layers.Softmax
 }
-
+STACK_BTYPE='stack'
+CONV_BTYPE='conv'
+INT_BTYPE=CONV_BTYPE
+DEFAULT_BTYPE=STACK_BTYPE
 
 
 
